==> tea_9.0.orig.tar.gz: tea-9.0/src/rox_strings.h <==
/***************************************************************************
                          rox_strings.h  -  description
                             -------------------
    begin                : Fri Oct 17 12:08:36 EEST 2003
    copyright            : (C) 2003-2004 by Peter 'Roxton' Semiletov
    email                : tea@list.ru
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
                                                
gchar* get_file_ver_name (const gchar *name);
size_t tNumber2Roman (guint uiNumber, int bUpperCase, char *szOutput);
GList* parse_string_to_list (gchar *s);
GList* add_to_glist_combined_st (GList *list, gchar* key, gchar *value);
GList* add_to_glist_combined_int (GList *list, gchar* key, gint value);
GList* remove_blank_lines (GList *lines);
void glist_strings_free (GList *list);
GList* glist_strings_sort (GList *list);
GList* glist_trim_l (GList* list, gint n);
GList* glist_trim_l_on_char (GList* list, gchar n);
GList* glist_enclose (GList* list, gchar *a, gchar *b);
void glist_print (GList *list);
void glist_save_to_file (GList *list, gchar *filename);
GList* load_file_to_glist (gchar *filename);
GList* add_to_glist_combined_str (GList *list, gchar *key, gchar *value);
GList* add_to_glist_combined_int (GList *list, gchar *key, gint value);
GList* str_in_glist (GList *list, gchar *st);
gchar* rep_all_s (gchar *s, gchar *r);
gchar* str_file_read (const gchar *filename);
GList* glist_shuffle (GList *list);
gchar* glist_enum (gchar *buf, gchar *format_str);
gboolean save_string_to_file (gchar *filename, gchar *s);
gchar* g_str_replace (const gchar *input, const gchar *replace, const gchar *with);
gchar* str_replace_all (gchar *s, gchar *what, gchar *to);
//GList* add_to_list_with_limit (GList *list, gchar *s, gint limit);
GList* glist_repl (GList* list, gchar *format);
GHashTable* load_file_to_hashtable (gchar *filename);
void print_ht (GHashTable *ht);
gchar* str_crackerize (gchar *buf);
gchar* str_eol_to_crlf (gchar *buf);
gint get_gchar_array_size (gchar **a);
gchar* morse_encode (gchar *s);
gchar* morse_decode (gchar *s);
GList* ht_to_glist (GHashTable *hash_table, gint option);
gchar* ch_str (gchar *s, gchar *new_val);
GList* each_line_remove_lt_spaces (GList *lines, gint mode);
//gint glist_get_str_index (GList *l, gchar *s);
gchar* get_c_header_fname (gchar *f);
gchar* get_c_source_fname (gchar *f);
gchar* ht_get_gchar_value (GHashTable *hash_table, gchar *key, gchar *def);
GList* str_remove_from_list (GList *list, gchar *s);
gchar* str_to_html (gchar *buf, gboolean xhtml);
gchar* text_load_gzip (gchar *filename);
gchar* locale_to_utf8 (gchar *s);
gchar* quotes_to_tex (gchar *buf);
gchar* tex_paras (gchar *buf);
gchar* string_from_glist_sep (GList *list, gchar *sep);
gchar* change_file_ext (gchar *filename, gchar *new_ext);
gchar* get_file_ext (gchar *filename);
gboolean str_in (gchar *s, gchar *ext1, ...);
gchar* read_xml_text (gchar *filename, gchar *xml_file, gchar *para);
gchar* read_abw_text (gchar *filename, gchar *xml_file, gchar *para);
gchar* separated_table_to_latex_tabular (const gchar *st, gchar *sep);
gint find_str_index (GList *l, gchar *s);
GList* filter_list (const GList *list, gchar *phrase, gboolean incld);
gchar* kill_str_by_size (gchar *s, gint val, gboolean killlesser);

==> tea_11.0.orig.tar.gz: tea-11.0/src/rox_strings.h <==
/***************************************************************************
                          rox_strings.h  -  description
                             -------------------
    begin                : Fri Oct 17 12:08:36 EEST 2003
    copyright            : (C) 2003-2005 by Peter 'Roxton' Semiletov
    email                : peter.semiletov@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
                                                
gchar* get_file_ver_name (const gchar *name);
size_t tNumber2Roman (guint uiNumber, int bUpperCase, char *szOutput);
GList* parse_string_to_list (gchar *s);
GList* add_to_glist_combined_st (GList *list, gchar* key, gchar *value);
GList* add_to_glist_combined_int (GList *list, gchar* key, gint value);
GList* remove_blank_lines (GList *lines);
void glist_strings_free (GList *list);
GList* glist_strings_sort (GList *list);
GList* glist_trim_l (GList* list, gint n);
GList* glist_trim_l_on_char (GList* list, gchar n);
GList* glist_enclose (GList* list, gchar *a, gchar *b);
void glist_print (GList *list);
void glist_save_to_file (GList *list, gchar *filename);
GList* load_file_to_glist (gchar *filename);
GList* add_to_glist_combined_str (GList *list, gchar *key, gchar *value);
GList* add_to_glist_combined_int (GList *list, gchar *key, gint value);
GList* str_in_glist (GList *list, gchar *st);
gchar* rep_all_s (gchar *s, gchar *r);
gchar* str_file_read (const gchar *filename);
GList* glist_shuffle (GList *list);
gchar* glist_enum (gchar *buf, gchar *format_str);
gboolean save_string_to_file (gchar *filename, gchar *s);
gchar* g_str_replace (const gchar *input, const gchar *replace, const gchar *with);
gchar* str_replace_all (gchar *s, gchar *what, gchar *to);
GList* glist_repl (GList* list, gchar *format);
GHashTable* load_file_to_hashtable (gchar *filename);
void print_ht (GHashTable *ht);
gchar* str_crackerize (gchar *buf);
gchar* str_eol_to_crlf (gchar *buf);
gint get_gchar_array_size (gchar **a);
gchar* morse_encode (gchar *s);
gchar* morse_decode (gchar *s);
GList* ht_to_glist (GHashTable *hash_table, gint option);
gchar* ch_str (gchar *s, gchar *new_val);
GList* each_line_remove_lt_spaces (GList *lines, gint mode);
gchar* get_c_header_fname (gchar *f);
gchar* get_c_source_fname (gchar *f);
gchar* ht_get_gchar_value (GHashTable *hash_table, gchar *key, gchar *def);
GList* str_remove_from_list (GList *list, gchar *s);
gchar* str_to_html (gchar *buf, gboolean xhtml);
gchar* text_load_gzip (gchar *filename);
gchar* locale_to_utf8 (gchar *s);
gchar* quotes_to_tex (gchar *buf);
gchar* tex_paras (gchar *buf);
gchar* string_from_glist_sep (GList *list, gchar *sep);
gchar* change_file_ext (gchar *filename, gchar *new_ext);
gchar* get_file_ext (gchar *filename);
gboolean str_in (gchar *s, gchar *ext1, ...);
gchar* read_xml_text (gchar *filename, gchar *xml_file, gchar *para);
gchar* read_abw_text (gchar *filename, gchar *xml_file, gchar *para);
gchar* separated_table_to_latex_tabular (const gchar *st, gchar *sep);
gint find_str_index (GList *l, gchar *s);
GList* filter_list (const GList *list, gchar *phrase, gboolean incld);
gchar* kill_str_by_size (gchar *s, gint val, gboolean killlesser);
gint glist_get_str_pos (GList *list, gchar *st);
gchar* copied_from_browser_to_ftext (const gchar *s, const gchar *pattern);
gchar* get_charset_from_meta (gchar *text);
void gslist_strings_free (GSList *list);
